==> haskell-deriving-aeson-0.2.6.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deriving-aeson
version:              0.2.6.1
visibility:           public
id:                   deriving-aeson-0.2.6.1-LLdQZS9P7Vp1b31OTYPipD
key:                  deriving-aeson-0.2.6.1-LLdQZS9P7Vp1b31OTYPipD
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  19ee6b6251bdb0a591063fc954e3bb07
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-8.10.4/site-local/deriving-aeson-0.2.6.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/deriving-aeson-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/deriving-aeson-0.2.6.1
hs-libraries:         HSderiving-aeson-0.2.6.1-LLdQZS9P7Vp1b31OTYPipD
depends:              aeson-1.5.6.0-4fHNEU34DqGLin6g6nejhx base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deriving-aeson-0.2.6.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deriving-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deriving-aeson
version:              0.2.6.1
visibility:           public
id:                   deriving-aeson-0.2.6.1-DQHq1uhU2Fk9yZle6Rb4AR
key:                  deriving-aeson-0.2.6.1-DQHq1uhU2Fk9yZle6Rb4AR
license:              BSD-3-Clause
copyright:            Copyright (c) 2020 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Type driven generic aeson instance customisation
description:
    This package provides a newtype wrapper with
    FromJSON/ToJSON instances customisable via a phantom type parameter.
    The instances can be rendered to the original type using DerivingVia.

category:             JSON, Generics
abi:                  80b7f681edfea12ce84736bb7cf4f784
exposed:              True
exposed-modules:      Deriving.Aeson Deriving.Aeson.Stock
import-dirs:          /usr/lib/ghc-8.10.4/site-local/deriving-aeson-0.2.6.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/deriving-aeson-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/deriving-aeson-0.2.6.1
hs-libraries:         HSderiving-aeson-0.2.6.1-DQHq1uhU2Fk9yZle6Rb4AR
depends:              aeson-1.5.6.0-KKLnIH6l1ju5f1LsAaB2FK base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-deriving-aeson/html/deriving-aeson.haddock

haddock-html:         /usr/share/doc/haskell-deriving-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
